@@ -5,7 +5,7 @@ import pytest
 import six
 
 
-@pytest.fixture(scope='function')
+@pytest.fixture(scope="function")
 def tmp_file(tmpdir):
     @contextlib.contextmanager
     def _tmp_file_cm(file_contents):
